@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2020 Marco Favorito
+# Copyright 2020-2021 Marco Favorito
 #
 # ------------------------------
 #
@@ -21,12 +21,4 @@
 #
 """Top-level package for TempRL."""
 
-import logging
-
-logging.getLogger("temprl").addHandler(logging.NullHandler())
-logging.basicConfig(
-    format="[%(asctime)s][%(name)s][%(funcName)s][%(levelname)s]: %(message)s",
-    level=logging.DEBUG,
-)
-
-__version__ = "0.2.3"
+__version__ = "0.3.0"
